---
# https://vitepress.dev/reference/default-theme-home-page
layout: home
title: TurkiyeAPI
description: Türkiye'nin idari yapısı için REST API

hero:
  name: 'TurkiyeAPI'
  text: "Türkiye'nin idari yapısı için REST API"
  tagline: TurkiyeAPI, Türkiye'nin iller, ilçeler, mahalleler ve köyler dahil olmak üzere idari bölümleri hakkında demografik ve coğrafi verilerle ayrıntılı bilgi sağlayan kapsamlı bir REST API'dır.
  image:
    src: /logo.png
    alt: TurkiyeAPI Logo
  actions:
    - theme: brand
      text: Rehber
      link: /tr/v1/guide/welcome
    - theme: alt
      text: GitHub
      link: https://github.com/ubeydeozdmr/turkiye-api

features:
  - title: REST API
    details: TurkiyeAPI, REST API standartlarına uygun olarak tasarlanmıştır.
  - title: Kapsamlı Veri Seti
    details: Türkiye'nin birçok idari bölümü hakkında ayrıntılı bilgi sağlar.
  - title: Açık Kaynak
    details: TurkiyeAPI, MIT lisansı altında açık kaynaklı bir projedir ve herkese açıktır.
  - title: Filtreleme, Sıralama ve Sayfalama
    details: TurkiyeAPI'de filtreleme, sıralama ve sayfalama özellikleri bulunmaktadır.
---
